(let*
  (
    (font (get-font "-adobe-helvetica-medium-r-normal-*-12*-*-*-*-p-*-iso8859-1"))
    (font-colors (list "grey30"
                       "black"))
    
    (title-width
      (lambda (w)
        (let
          ((w-width (car (window-dimensions w))))
          (max 0 (min (- w-width 63) (text-width (window-name w) font))))))
          
    (update-title-width
      (lambda (w)
        (if (eq (window-get w 'current-frame-style) 'Bubbles-Revisited)
          (rebuild-frame w))))
    
    (title-images (list (make-image "title-inactive.png")
                        (make-image "title-active.png")))
    (title-shaded-images (list (make-image "title-shaded-inactive.png")
                               (make-image "title-shaded-active.png")))
    (leftcap-images (list (make-image "leftcap-inactive.png")
                          (make-image "leftcap-active.png")))
    (leftcap-shaded-images (list (make-image "leftcap-shaded-inactive.png")
                                 (make-image "leftcap-shaded-active.png")))
    (rightcap-images (list (make-image "rightcap-inactive.png")
                           (make-image "rightcap-active.png")))
    (rightcap-shaded-images (list (make-image "rightcap-shaded-inactive.png")
                                  (make-image "rightcap-shaded-active.png")))
    (left-images (list (make-image "left-inactive.png")
                       (make-image "left-active.png")))
    (right-images (list (make-image "right-inactive.png")
                        (make-image "right-active.png")))
    (bottom-images (list (make-image "bottom-inactive.png")
                         (make-image "bottom-active.png")))
    (top-images (list (make-image "top-inactive.png")
                      (make-image "top-active.png")))
    (bottomleft-images (list (make-image "bottomleft-inactive.png")
                             (make-image "bottomleft-active.png")))
    (bottomright-images (list (make-image "bottomright-inactive.png")
                              (make-image "bottomright-active.png")))
    (topleft-images (list (make-image "topleft-inactive.png")
                          (make-image "topleft-active.png")))
    (topright-images (list (make-image "topright-inactive.png")
                           (make-image "topright-active.png")))
    (background-image (make-image "bg.png"))
    (close-images (list (make-image "close-normal.png")
                        (make-image "close-normal.png")
                        (make-image "close-prelight.png")
                        (make-image "close-clicked.png")))
    (maximize-images (list (make-image "maximize-normal.png")
                           (make-image "maximize-normal.png")
                           (make-image "maximize-prelight.png")
                           (make-image "maximize-clicked.png")))
    (iconify-images (list (make-image "iconify-normal.png")
                          (make-image "iconify-normal.png")
                          (make-image "iconify-prelight.png")
                          (make-image "iconify-clicked.png")))

    (frame `(
	((background . ,background-image)
	 (top-edge . -16)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . title))
	((background . ,top-images)
	 (top-edge . -23)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . top-border))
	((background . ,bottom-images)
	 (bottom-edge . -7)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . bottom-border))
	((background . ,right-images)
	 (right-edge . -7)
	 (top-edge . -16)
	 (bottom-edge . 0)
	 (class . right-border))
	((background . ,left-images)
	 (left-edge . -7)
	 (top-edge . -16)
	 (bottom-edge . 0)
	 (class . left-border))
	((background . ,topleft-images)
	 (left-edge . -7)
	 (top-edge . -23)
	 (class . top-left-corner))
	((background . ,bottomleft-images)
	 (left-edge . -7)
	 (bottom-edge . -7)
	 (class . bottom-left-corner))
	((background . ,bottomright-images)
	 (right-edge . -7)
	 (bottom-edge . -7)
	 (class . bottom-right-corner))
	((background . ,topright-images)
	 (right-edge . -7)
	 (top-edge . -23)
	 (class . top-right-corner))
	((background . ,leftcap-images)
	 (left-edge . -7)
	 (top-edge . -23)
	 (class . title))
	((background . ,title-images)
	 (foreground . ,font-colors)
	 (font . ,font)
	 (x-justify . center)
	 (y-justify . 3)
	 (text . ,window-name)
	 (left-edge . 3)
	 (top-edge . -23)
         (width . ,(lambda (w) (title-width w)))
	 (class . title))
	((background . ,rightcap-images)
	 (left-edge . ,(lambda (w) (+ (title-width w) 3)))
	 (top-edge . -23)
	 (class . title))
	((background . ,close-images)
	 (right-edge . 1)
	 (top-edge . -17)
	 (class . close-button))
	((background . ,iconify-images)
	 (right-edge . 17)
	 (top-edge . -17)
	 (class . iconify-button))
	((background . ,maximize-images)
	 (right-edge . 33)
	 (top-edge . -17)
	 (class . maximize-button))
      ))
      
    (shaped-frame `(
	((background . ,leftcap-shaded-images)
	 (left-edge . -7)
	 (top-edge . -23)
	 (class . title))
	((background . ,title-shaded-images)
	 (foreground . ,font-colors)
	 (font . ,font)
	 (x-justify . center)
	 (y-justify . 3)
	 (text . ,window-name)
	 (left-edge . 3)
	 (top-edge . -23)
         (width . ,(lambda (w) (title-width w)))
	 (class . title))
	((background . ,rightcap-shaded-images)
	 (left-edge . ,(lambda (w) (+ (title-width w) 3)))
	 (top-edge . -23)
	 (class . title))
      ))
      
      (transient-frame `(
	((background . ,background-image)
	 (top-edge . -16)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . title))
	((background . ,top-images)
	 (top-edge . -23)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . top-border))
	((background . ,bottom-images)
	 (bottom-edge . -7)
	 (left-edge . 0)
	 (right-edge . 0)
	 (class . bottom-border))
	((background . ,right-images)
	 (right-edge . -7)
	 (top-edge . -16)
	 (bottom-edge . 0)
	 (class . right-border))
	((background . ,left-images)
	 (left-edge . -7)
	 (top-edge . -16)
	 (bottom-edge . 0)
	 (class . left-border))
	((background . ,topleft-images)
	 (left-edge . -7)
	 (top-edge . -23)
	 (class . top-left-corner))
	((background . ,bottomleft-images)
	 (left-edge . -7)
	 (bottom-edge . -7)
	 (class . bottom-left-corner))
	((background . ,bottomright-images)
	 (right-edge . -7)
	 (bottom-edge . -7)
	 (class . bottom-right-corner))
	((background . ,topright-images)
	 (right-edge . -7)
	 (top-edge . -23)
	 (class . top-right-corner))
	((background . ,close-images)
	 (right-edge . 1)
	 (top-edge . -17)
	 (class . close-button))
      ))
    )

  (add-frame-style 'Bubbles-Revisited
    (lambda (w type)
      (case type 
            ((transient) transient-frame)
            ((shaped-transient) shaped-frame)
            ((shaped) shaped-frame)
            ((default)frame))))
            
  (call-after-property-changed 'WM_NAME update-title-width)
)
